Hourly — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »

# Hourly

Obtient les données météorologiques, les traite, prépare les fichiers de graphes & textes et les téléverse sur un site web.

Exécuté à partir d’une tâche cron, en règle générale toutes les heures.

    usage: python -m pywws.Hourly [options] data_dir
    options are:
     -h or --help     display this help
     -v or --verbose  increase amount of reassuring messages
    data_dir is the root directory of the weather data (e.g. $(HOME)/weather/data)

Ce script ne fait guère plus que d’appeler d’autres modules dans l’ordre pour obtenir les données de la station météo, les traiter, tracer des graphes, de générer des fichiers texte et transférer le résultat vers un site web.

Pour plus d’informations sur l’utilisation de `Hourly.py`, voir Comment configurer la journalisation horaire avec pywws.

Fonctions

`Hourly`(data_dir) |
`main`([argv]) |

`pywws.Hourly.` `Hourly`(data_dir)

`pywws.Hourly.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »